# $Header: /home/cvsroot/zSQLgate/DBIServer/Intro.pm,v 1.10 2002/10/08 16:17:11 mike Exp $

package Net::Z3950::DBIServer::Intro;
use strict;


=head1 NAME

Net::Z3950::DBIServer::Intro - An Introduction to zSQLgate


=head1 SYNOPSIS

C<zSQLgate> is a generic gateway between the Z39.50 Information
Retrieval protocol and pretty much any relational database you
care to mention - or, to say the same thing a different way, it
provides an Z39.50 interface to your relational databases.

The Perl module L<Net::Z3950::DBIServer> provides the guts of the
gateway.  Both the C<zSQLgate> program and the
C<Net::Z3950::DBIServer> module are included in this distribution.

=head1 DESCRIPTION

The Z39.50 information retrieval protocol (now ratified as
international standard ISO 23950) is a mature and powerful protocol
used in application domains as diverse as bibliographic information,
geo-spatial mapping, cultural heritage,
and structured vocabulary navigation.  It's particularly useful in
distributed systems that need to provide uniform access to a variety
of different information resources, and has therefore provided the
technical backbone of many European and international collaborative
projects.

Relational database managegement systems (or RDBMSs) have been with us
for decades, but don't seem to be showing any signs of going away yet
:-)  The ubiquitous SQL language, which is used to search them, has its
roots three decades ago in 1973, when an early version (then called
``Sequel'') was described in R. F. Boyce and D. D. Chamberlin's paper
I<Using a Structured English Query Language as a Data Definition
Facility> (I<IBM RJ 1381>, December).

Z39.50 and relational databases may seem to belong to separate
universes, but in practice they often need to play nicely
together.  Many, perhaps most, Z39.50 servers are built on top of
relational databases; and many IR projects need to add Z39.50
interfaces to existing relational databases.

This has traditionally been an awkward and error-prone process, as
most of the available tools are rather low-level, and require
extensive programming.  C<zSQLgate> aims to change that by providing a
generic Z39.50-to-relational-database gateway - a Z39.50 server which
serves the data from a relational database.  Instead of requiring
programming, setting it up is a matter of writing a relatively
straightforward configuration file.


=head1 WHO NEEDS zSQLgate?

I<You> do!

Er, let me try that again.  You may need C<zSQLgate> if:

=over 4

=item *

You already have an established project built on Oracle, Sybase,
PostgreSQL, MySQL or any of a seemingly infinite number of
alternatives, and you need to build an Z39.50 interface to it.

Z<>

=item *

You have a wide variety of relational databases, similar in concept
but different in the details, possibly running on different machines
and using different RDBMSs; and you want to build a single interface that
treats them all uniformly.

Z<>

=item *

You want to build a Z39.50 server from scratch, and for some reason
dedicated tools such as Index Data's Z'mbol -
http://www.indexdata.dk/zmbol/ - are not suitable.  You may want to
use a relational database because you're used to it, or because you
need industrial-strength data integrity, or commit/rollback, or some
other feature of a particular RDBMS.

Z<>

=back


=head1 Z39.50 CAPABILITIES

Part of the strength, and also part of the weakness, of Z39.50 is the
fact that it is not a monolithic standard: implementations are not
required to implement all of it - indeed, there is probably I<no>
Z39.50 implementation that supports the whole standard - but only
those parts which are useful to it.

In this section, we briefly discuss which parts of the Z39.50 standard
C<zSQLgate> supports.

=head2 Searching

I<###> attributes

=head2 Retrieval

C<zSQLgate> currently supports retrieval using the following record
syntaxes:

=over 4

=item XML

I<###>

=item GRS-1

I<###>
The GRS-1 support is not fully in place: the hooks are
there in the configuration-file parser and elsewhere, but the current
version of C<zSQLgate> does not actually generate GRS-1 records.  That
bug will be fixed Real Soon Now!

=item SUTRS

I<###>

=back

There is not yet any support for the MARC family of record syntaxes.
That will be along just as soon as someone has a need for it.

=head2 Other

C<zSQLgate> does not currently include any support for Z39.50's
C<sort>, C<scan> or C<extended services>.  This functionality can be
added if required: contact the author if you wish to build a server
that provides these services.


=head1 LIMITATIONS

C<zSQLgate> is focused on doing one thing well: that is, providing the
means for Z39.50 clients to search in, and fetch data from, relational
databases.  So it does not currently address any of the following:

=over 4

=item *

Database update.  C<zSQLgate> provides a read-only interface.

Z<>

=item *

Z39.50 ``extras'' such as inter-library loan (ILL).

Z<>

=item *

``Fan out'', or the provision of ``union catalogues'' (though this
could be added in subsequent versions if there's demand for it.)

Z<>

=back


=head1 FUTURE DIRECTIONS

I have big plans for extra functionality in C<zSQLgate>.  You can get
some idea of what I have in mind by reading the list of anticipated
extensions to the configuration file syntax,
L<Net::Z3950::DBIServer::Spec/FUTURE DIRECTIONS>
(skip over that document's BNF grammar if that kind of thing freaks
you out.)

I plan to implement these enhancements more or less in the order that
customers need them, so do give me a shout if anything listed here (or
indeed anything not listed) is high on your ``must have'' list, and
I'll see what I can do.


=head1 TERMS AND CONDITIONS

It's always my inclination to write Free Software (that's Free in the
sense of Freedom - see http://www.gnu.org/ - also known in more recent
times as Open Source Software - http://www.opensource.org/ ).  So for
example my Perl module for building Z39.50 clients, C<Net::Z3950> -
http://perl.z3950.org/ - is Free.  Likewise my Java implementation of
ZOOM - http://zoom.z3950.org/ - and various interpreters and utilities
for the rather silly ETA language, I<etc>.

However, it's come to my attention that there is one tiny flaw in this
approach to releasing software, and that's that I don't make any
money.  Now I would very much like not to be motivated by money,
concentrating only on the twin joys of creativity and altruism; but
unfortunately, my wife, my two small children, and most of all my
mortgage don't seem to understand this, however many times I explain
it.

So I'm trying something different with this module, and releasing it
on non-free terms - see L<Net::Z3950::DBIServer::LICENCE>.  In a
nutshell, you can download, unpack, build and evaluate it for free,
for you may not deploy it without first purchasing a deployment
licence.

The price of a deployment licence may be affected by factors such as
the number of copies you wish to run, the number of users, the
visibility of the Z39.50 server, etc., but as a rough guideline, I am
thinking in terms of either a 2000 one-off fee, or 1000 for a
one-year deployment licence and an additional 500 per year
thereafter.  That fee would include limited support and a small amount
of development work where appropriate.


=head1 NOW WHAT?

If you've not already read the licence, you should.
L<Net::Z3950::DBIServer::LICENCE>.
If you need help installing, you might find
L<Net::Z3950::DBIServer::Install>
helpful.
Then it's on to the the tutorial,
L<Net::Z3950::DBIServer::Tutorial>,
after which you may wish to go on to some of the more brutally
technical documents, including the configuration file specification,
L<Net::Z3950::DBIServer::Spec>.


=head1 AUTHOR

Mike Taylor E<lt>mike@miketaylor.org.ukE<gt>

First version Sunday 24th February 2002.

=cut

1;
